@@ -4,7 +4,8 @@ module JsImagePaths
     isolate_namespace(JsImagePaths)
 
     initializer('js_image_paths.compile', after: 'sprockets.environment') do |application|
-      application.assets.register_preprocessor('application/javascript', :'js_image_path.compile') do |context, data|
+      sprockets_env = application.assets || Sprockets
+      sprockets_env.register_preprocessor('application/javascript', :'js_image_path.compile') do |context, data|
         if context.logical_path == 'js_image_paths'
           JsImagePaths::Generator.context = context
         end
